##  Step 5: Update the Webhook with the Function URL
Once you've successfully tested the function, update the webhook with the function URL.
Follow these steps:
  1. On the user profile, select Administration, and then select Webhooks in the sidebar.
  2. On the Webhooks page, select the webhook that you created.
  3. In the Target URL field, enter the function URL.
  4. Click Save.


The automation is set up. To ensure that it works as expected, update the energy consumption value on a test fact sheet and verify that the corresponding tag is assigned.
